@@ -3,16 +3,9 @@ package Linux::Pid;
 use strict;
 use warnings;
 
-use Inline
-    C	    => <<'**C**',
-IV _getpid()  { return (IV)getpid(); }
-IV _getppid() { return (IV)getppid(); }
-**C**
-    VERSION => (our $VERSION = 0.03),
-    NAME    => __PACKAGE__;
-
-*getpid  = \&_getpid;
-*getppid = \&_getppid;
+our $VERSION = 0.04;
+require XSLoader;
+XSLoader::load('Linux::Pid', $VERSION);
 
 sub import {
     shift;
@@ -59,7 +52,7 @@ underlying C functions C<getpid()> and C<getppid()>.
 
 =head1 AUTHOR
 
-Copyright (c) 2002-2004 Rafael Garcia-Suarez. All rights reserved. This
+Copyright (c) 2002-2007 Rafael Garcia-Suarez. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
